<?php

// Copy this code into your theme's functions.php file

/**
 * Our custom notification helper function. Use this to add messages to the 
 * notifications heap during execution of your theme/function code
 */
function custom_notification_helper($message, $type)
{

    if(!is_admin()) {
        return false;
    }

    // todo: check these are valid
    if(!in_array($type, array('error', 'info', 'success', 'warning'))) {
        return false;
    }

    // Store/retrieve a transient associated with the current logged in user
    $transientName = 'admin_custom_notification_'.get_current_user_id();

    // Check if this transient already exists. We can use this to add
    // multiple notifications during a single pass through our code
    $notifications = get_transient($transientName);

    if(!$notifications) {
        $notifications = array(); // initialise as a blank array
    }

    $notifications[] = array(
        'message' => $message,
        'type' => $type
    );

    set_transient($transientName, $notifications);  // no need to provide an expiration, will
                                                    // be removed immediately

}

/**
 * The handler to output our admin notification messages
 */
function custom_admin_notice_handler() {

    if(!is_admin()) {
        // Only process this when in admin context
        return;
    }

    $transientName = 'admin_custom_notification_'.get_current_user_id();

    // Check if there are any notices stored
    $notifications = get_transient($transientName);

    if($notifications):
        foreach($notifications as $notification):
            echo <<<HTML

                <div class="notice notice-custom notice-{$notification['type']} is-dismissible">
                    <p>{$notification['message']}</p>
                </div>

HTML;
        endforeach;
    endif;

    // Clear away our transient data, it's not needed any more
    delete_transient($transientName);

}
add_action( 'admin_notices', 'custom_admin_notice_handler' );


/**
 * A simple little function to help test this functionality. Call
 * e.g. http://yoursite.com/wp-admin/?test_admin_notices to check
 * if this is working
 */
function test_custom_admin_notices()
{
    if(isset($_GET['test_admin_notices'])) {
        custom_notification_helper('Custom error notice', 'error');
        custom_notification_helper('Custom success notice', 'success');
        custom_notification_helper('Custom warning notice', 'warning');
        custom_notification_helper('Custom info notice', 'info');
        // Simulate a redirect
        header('Location: index.php');
        exit;
    }
}
add_action('admin_init', 'test_custom_admin_notices');



// Part 2


add_action('admin_head', 'add_notification_styling');
function add_notification_styling()
{
    echo <<<HTML
    <style>

        @keyframes custom-notification-wiggle {
          10%, 90% {
            transform: translate3d(-1px, 0, 0);
          }
          
          20%, 80% {
            transform: translate3d(2px, 0, 0);
          }

          30%, 50%, 70% {
            transform: translate3d(-4px, 0, 0);
          }

          40%, 60% {
            transform: translate3d(4px, 0, 0);
          }
        }

        .notice-custom.notice-error.active-wiggle {
            animation: custom-notification-wiggle 0.5s cubic-bezier(0.645, 0.045, 0.355, 1) both;
        }

        .notice-custom.notice-warning.active-wiggle {
            animation: custom-notification-wiggle 0.25s cubic-bezier(0.645, 0.045, 0.355, 1) both;
        }

    </style>
HTML;
}

add_action('admin_head', 'add_notification_scripting');

function add_notification_scripting()
{
    echo <<<HTML
    <script type='text/javascript'>

        jQuery(function($){
            $('.notice-custom.notice-error, .notice-custom.notice-warning').addClass('active-wiggle');
        });

    </script>
HTML;
}
